@@ -1,5 +1,5 @@
 package Dios;
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 use 5.014; use warnings;
 use Dios::Types;
@@ -843,7 +843,7 @@ Dios - Declarative Inside-Out Syntax
 
 =head1 VERSION
 
-This document describes Dios version 0.000002
+This document describes Dios version 0.000003
 
 
 =head1 SYNOPSIS
@@ -901,6 +901,11 @@ between Perl 5 and Perl 6 make that impractical, in which cases the
 module attempts to provide a replacement syntax (or semantics) that is
 likely to be unsurprising to experienced Perl 5 programmers.
 
+B<Note:> This module relies on the Keyword::Declare module, which is still
+in alpha, and which still has compile-time performance issues. Expect slow
+compiles, but then fast execution. The slow compiles will disappear as
+Keyword::Declare improves.
+
 
 =head1 INTERFACE
 
